@@ -89,7 +89,7 @@ namespace libdar
 	    /// slice for a given position. For compatibility with older DAR format, it is thus important
 	    /// to not change the value returned by this class method. This call is only used
 	    /// when reading archive generated by old versions of dar < 2.4.0. (aka archive format <= 7)
-        static U_I min_size() { return sizeof(magic_number) + sizeof(label) + 2*sizeof(char); };
+        static U_I min_size() { return sizeof(magic_number) + label::common_size() + 2*sizeof(char); };
 
 
 	    // fields access methods
